/* 8BitAmEthernet
 * version 0.3.1 date 2006-03-12
 * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
 * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
 * a project of CCC-AC - http://www.cccac.de/
 */

#ifndef INC_eeprom
#define INC_eeprom

//flags for what needs to be written to the EEPROM
#define EepromNeedWriteMac 0x01
#define EepromNeedWriteIp 0x02
#define EepromNeedWriteMask 0x04
#define EepromNeedWriteGw 0x08
#define EepromNeedWriteS8pPort 0x10
#define EepromNeedWriteS8pKey 0x20
#define EepromNeedWriteHttpPort 0x40
#define EepromNeedWriteDefOut 0x80
extern unsigned char EepromNeedWrite;

//get configuration from EEPROM
extern void EepromGetConfig( void );

//task function to do the work - call from main loop
extern void EepromTask( void );

#endif //#ifndef INC_eeprom
